@@ -3106,7 +3106,7 @@ exchange_mapi_create_profile (const char *username, const char *password, const
 	}
 	d(g_print("MapiLogonProvider : succeeded \n"));
 
-	retval = ProcessNetworkProfile(session, username, callback, NULL); 
+	retval = ProcessNetworkProfile(session, username, callback, data); 
 	if (retval != MAPI_E_SUCCESS) {
 		manage_mapi_error ("ProcessNetworkProfile", GetLastError(), error_msg);
 		g_debug ("Deleting profile %s ", profname); 
